@@ -87,19 +87,6 @@ public:
     {
     }
 
-    static inline bool isPluginEnabled(const KConfigGroup &config, const KPluginMetaData &plugin)
-    {
-        const auto pluginName = plugin.pluginId();
-        qCDebug(KAMD_LOG_APPLICATION) << "Plugin Name is " << pluginName << plugin.fileName();
-
-        if (pluginName == QLatin1String("org.kde.ActivityManager.ResourceScoring")) {
-            // SQLite plugin is necessary for the proper workspace behaviour
-            return true;
-        } else {
-            return config.readEntry(pluginName + QStringLiteral("Enabled"), plugin.isEnabledByDefault());
-        }
-    }
-
     bool loadPlugin(const KPluginMetaData &plugin);
 
     Resources *resources;
@@ -121,7 +108,6 @@ Application::Application(int &argc, char **argv)
 
 void Application::init()
 {
-
     // KAMD is a daemon, if it crashes it is not a problem as
     // long as it restarts properly
     // TODO: Restart on crash
@@ -183,8 +169,7 @@ void Application::loadPlugins()
 {
     using namespace std::placeholders;
 
-    const auto config = KSharedConfig::openConfig(QStringLiteral("kactivitymanagerdrc"))->group("Plugins");
-    const auto offers = KPluginMetaData::findPlugins(QStringLiteral(KAMD_PLUGIN_DIR), std::bind(Private::isPluginEnabled, config, _1));
+    const auto offers = KPluginMetaData::findPlugins(QStringLiteral(KAMD_PLUGIN_DIR), {}, KPluginMetaData::AllowEmptyMetaData);
     qCDebug(KAMD_LOG_APPLICATION) << "Found" << offers.size() << "enabled plugins:";
 
     for (const auto &offer : offers) {
@@ -194,8 +179,7 @@ void Application::loadPlugins()
 
 bool Application::loadPlugin(const QString &pluginId)
 {
-    auto offer = KPluginMetaData::findPluginById(QStringLiteral(KAMD_PLUGIN_DIR), pluginId);
-
+    auto offer = KPluginMetaData::findPluginById(QStringLiteral(KAMD_PLUGIN_DIR), pluginId, KPluginMetaData::AllowEmptyMetaData);
     if (!offer.isValid()) {
         qCWarning(KAMD_LOG_APPLICATION) << "[ FAILED ] not found: " << pluginId;
         return false;
@@ -281,3 +265,5 @@ QStringList Application::loadedPlugins() const
 {
     return d->pluginIds;
 }
+
+#include "moc_Application.cpp"
